PCB Environment: /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/TriList.hpp Source File

PCB Environment 2

Loading...
Searching...
No Matches
TriList.hpp
1
2#ifndef GYM_PCB_UI_TRILIST_H
3#define GYM_PCB_UI_TRILIST_H
4
5#include "GLContext.hpp"
6#include "Color.hpp"
7#include "Geometry.hpp"
8#include <vector>
9
10class Camera;
11
12 class TriList
13{
14public:
15 TriList(const PCBoard&);
16 ~TriList();
17 void update(const PCBoard&);
18 void setLineWidth(float w) { mLineWidthBase = w; }
19 void draw(const Camera&);
20private:
21 uint mNumTris{0};
22 float mLineWidthBase{1.0f};
23 GLuint mVBO{0};
24 GLuint mIBO{0};
25 GLuint mVAO{0};
26
27 static GLuint sVP, sFP;
28 static GLuint sPP;
29 static GLint sUniformFillAlpha;
30
31 void createVAO();
32 static void createShaders();
33};
34
35#endif // GYM_PCB_UI_TRILIST_H
Camera
Definition Camera.hpp:15
PCBoard
Definition PCBoard.hpp:36